import pytest

from pytest_depends_on.consts.status import Status


# def test_parent() -> None:
#     assert True


@pytest.mark.depends_on(tests=["test_parent"], status=Status.PASSED)
def test_child_a() -> None:
    assert True


@pytest.mark.depends_on(tests=["test_parent"], status=Status.FAILED)
def test_child_b() -> None:  # expected to status "SKIPPED"
    assert True


def test_parent() -> None:
    assert True
